@@ -15,6 +15,9 @@ class PelicanMathSettings:
             "pelican-math-svg"
         ).version
 
+        self.scale_display: float | tuple[float, float] = 1.0
+        self.scale_inline: float | tuple[float, float] = 1.0
+
         self.latex_preamble: list[str] = [
             r"\documentclass[crop,border={2pt 0pt}]{standalone}",
             r"\usepackage{amsmath}",
@@ -51,6 +54,8 @@ class PelicanMathSettings:
     def serialize(self) -> str:
         obj: dict[str, Any] = {
             "plugin_version": self.plugin_version,
+            "scale_inline": self.scale_inline,
+            "scale_display": self.scale_display,
             "latex": {
                 "args": self.latex_args,
                 "preamble": self.latex_preamble,
@@ -81,6 +86,9 @@ class PelicanMathSettings:
         if settings is None:
             return obj
 
+        obj.scale_inline = settings.get("scale_inline", obj.scale_inline)
+        obj.scale_display = settings.get("scale_display", obj.scale_display)
+
         if "scour" in settings:
             obj.scour = settings["scour"].get("enabled", obj.scour)
             obj.scour_args = settings["scour"].get("args", obj.scour_args)
